package de.tu_darmstadt.tk.SmartHomeNetworkSim.core;

/**
 * Representation of connection EndPoints, which allows configuration of timings
 * and if it reacts to incoming traffic or even triggers new connections.
 * 
 * @author Andreas T. Meyer-Berg
 */
public class Port {

	/**
	 * A closed Port which does not react to incoming traffic
	 */
	public final short CLOSED = 0;

	/**
	 * Open Port which reacts to incoming traffic
	 */
	public final short OPEN = 1;

	/**
	 * Open Port which reacts to incoming traffic and sends packets every
	 * triggerInterval
	 */
	public final short SENDING = 2;

	/**
	 * Status of the Port, wethere it is CLOSED, OPEN or SENDING
	 */
	private short status;

	/**
	 * SmartDevice which owns the port
	 */
	private SmartDevice owner;

	/**
	 * Constant time interval, which triggers new traffic every
	 * {@code triggerInterval} milliseconds.
	 */
	private long triggerInterval;

	/**
	 * Last timestep traffic was triggered
	 */
	private long lastTrigger;

	/**
	 * Time in milliseconds needed for responds to incoming 
	 */
	private short responseTime;

	/**
	 * Port number of this Port.
	 */
	private short portNumber;

	/**
	 * @return the status
	 */
	public short getStatus() {
		return status;
	}

	/**
	 * @param status
	 *            the status to set
	 */
	public void setStatus(short status) {
		this.status = status;
	}

	/**
	 * @return the owner
	 */
	public SmartDevice getOwner() {
		return owner;
	}

	/**
	 * @param owner
	 *            the owner to set
	 */
	public void setOwner(SmartDevice owner) {
		this.owner = owner;
	}

	/**
	 * @return the triggerInterval
	 */
	public long getTriggerInterval() {
		return triggerInterval;
	}

	/**
	 * @param triggerInterval
	 *            the triggerInterval to set
	 */
	public void setTriggerInterval(long triggerInterval) {
		this.triggerInterval = triggerInterval;
	}

	/**
	 * @return the responseTime
	 */
	public short getResponseTime() {
		return responseTime;
	}

	/**
	 * @param responseTime
	 *            the responseTime to set
	 */
	public void setResponseTime(short responseTime) {
		this.responseTime = responseTime;
	}

	/**
	 * @return the portNumber
	 */
	public short getPortNumber() {
		return portNumber;
	}

	/**
	 * @param portNumber
	 *            the portNumber to set
	 */
	public void setPortNumber(short portNumber) {
		this.portNumber = portNumber;
	}

}
